=========
ChangeLog
=========


v0.1.29
=======

* Corrected reStructuredText section title rendering
* Corrected DocTree structure (switch "container" to "section" node)
* Removed non-matching extensions from manifest


v0.1.28
=======

* Added suppression of lone-section collapsing into document
* Added support for `format.rst.filters` option
* Small improvement to rST output writer (text escaping)
* Added support for inline email addresses in rST writer


v0.1.27
=======

* First tagged release
